#ifndef _KYSEC_BWLIST_H
#define _KYSEC_BWLIST_H

#ifdef __cplusplus
extern "C" {
#endif


/* kylin_bwlist.xml 存放的是软件黑白名单信息 */

/*
 * 创建xml文档
 * 返回值:     -1:出错 0:文档已经存在 n(>0):新建xml文档，n个字节被写入文档
 */
int kylin_bwlist_create(void);

/*
 * 添加一个黑白名单节点信息到xml文件中
 * @bw_value:   黑名单或白名单节点("white" or "black", 其它值不合法)
 * @debname:    添加到黑名单或者白名单的包名；
 * 返回值:      0:成功，-1:出错, 1：软件包已经在列表, -2：未授权
 */
int kylin_bwlist_add(char *bw_value, char *debname);

/*
 * 获取黑白名开关标识
 * 返回值：0:未开启黑白名单，1：开启白名单，2：开启黑名单, -1:出错
 */
int kylin_bwlist_get_root_distinguish(void);

/*
 * 设置黑白名开关标识
 * @value: 0:不开启黑白名单，1：开启白名单，2：开启黑名单， 其它值非法
 * 返回值：0:成功，非0:失败, -2：未授权
 */
int kylin_bwlist_set_root_distinguish(int value);

/*
 * 获取黑名单、白名单节点数据
 * @bw_value: 黑名单节点或者白名单节点
 * 返回值：包含黑名单或者白名单节点中包名，count为列表中包的个数,返回的二级指针需要自己释放内存
 */
char **kylin_bwlist_read_all_node_with_uid(char *bw_value, int *count);

/*
 * 清空列表
 *　返回值：-1失败，0 删除节点成功, n(>0):新建xml文档，n个字节被写入文档, -2：未授权
 */
int kylin_bwlist_clear(void);

/*
 * 删除一个黑白名单节点信息
 * @bw_value:   黑名单或白名单节点("white" or "black", 其它值不合法)
 * @debname:    删除黑名单或者白名单的包名；
 * 返回值:      0:不存在，-1:出错，1成功, -2：未授权
 */
int kylin_bwlist_del(char *bw_value, char *debname);

#ifdef __cplusplus
}
#endif

#endif // _KYSEC_NETCTL_H
